@@ -130,7 +130,6 @@ public:
 
 template<typename PIXFMT>
 class TextRenderer {
-  UTF_UCS converter;
   FontSettings last_font;
   agg::glyph_rendering last_gren;
   std::vector<textshaping::Point> loc_buffer;
@@ -144,9 +143,7 @@ class TextRenderer {
   bool no_bearings;
   
 public:
-  TextRenderer() :
-    converter()
-  {
+  TextRenderer() {
     last_gren = agg::glyph_ren_native_mono;
     get_engine().hinting(true);
     get_engine().flip_y(true);
@@ -239,6 +236,10 @@ public:
     }
     
     int expected_max = strlen(string) * 16;
+    if (expected_max == 0) {
+      return;
+    }
+    
     loc_buffer.reserve(expected_max);
     id_buffer.reserve(expected_max);
     cluster_buffer.reserve(expected_max);
@@ -363,6 +364,7 @@ private:
       if (!get_engine().load_font(font.file, font.index, gren)) {
         return false;
       }
+      
       last_gren = gren;
       get_engine().height(size);
       get_engine().id(id);
